<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="he">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clear log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Today</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>3 days</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 week</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 month</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>3 months</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Emergency</source>
        <translation>חירום</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>אזהרה</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>קריטי</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>אזהרה</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>הערה</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>מידע</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>בידוק</translation>
    </message>
    <message>
        <source>Login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Boot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shutdown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Super critical</source>
        <translation>SUPER KРИTIΚAL</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>עקבות</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>הBOSEות זהות</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>ניצול של גישה מופרד</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>הBOSEות גישה חובה</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>רחוב</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>איסוף מסמכים</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>אחר</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation>zip(*.zip)</translation>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; דוקument (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>מ eksρΟUt...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>מ eksρΟUt בהצלחה</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>מ eksρΟUt נכשל</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation>)(*הנתיב ל eksρΟUt לא זמין. אנא בחר נתיב אחר לפעולה eksρΟUt.</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>מ eksρΟUt קובץ</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>תקופה:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>_LVL:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>מצב:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>סוג אירוע:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>משתמש:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>פעולה:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>שם משתמש:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>&lt;=(נִקְרֵא בְּיַצֵּרָה)</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>תיעוד הפסקה</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>תיעוד כניסה</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>סוג בדיקה:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation>יישום:</translation>
    </message>
    <message>
        <source>Submodule:</source>
        <translation>מODULE שמאלי:</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>אזהרה</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>בידוק</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>מידע</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>חירום</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>אזהרה</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>קריטי</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>הערה</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>FOX</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>KRITI</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>קובץ ה_LOGGER_ ריק</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>הצג לוג</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>הצג לוג הוא-tooל שימושי להצגת לוגים של מערכת.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>אין תוצאות לחיפוש</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>חיפוש</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>_LVL_</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>התקדמות</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>תאריך וזמן</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>מידע</translation>
    </message>
    <message>
        <source>User</source>
        <translation>משתמש</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>מקור</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>פעולה</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>מצב</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>סוג אירוע</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>שם משתמש</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>_LVL:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>תהליך:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>תאריך וזמן:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>מידע:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>נULO</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>משתמש:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>שם קובץ</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>זמן שינוי</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation>SIG</translation>
    </message>
    <message>
        <source>EXE</source>
        <translation>EXE</translation>
    </message>
    <message>
        <source>Core File</source>
        <translation>קובץ קור</translation>
    </message>
    <message>
        <source>User Name </source>
        <translation>שם משתמש </translation>
    </message>
    <message>
        <source>Offset</source>
        <translation>ה疖ה</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>תאריך וזמן</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>로그 מערכת</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>לוג גירוס</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>לוג התחלה</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>לוג dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>לוג Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>לוג Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>לוג אפליקציות</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>אירוע התחלה-סיום</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>לוג dnf</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>לוג אחר</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>לוג משובח</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>לוג סטטוס안</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation>לוג מטיפוס</translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation>לא ניתן לקבל מידע על שגיאה, אנא התקן systemd-coredump.</translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>אין לך הרשאות להצגה</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation>_LVL של בטיחות מערכת זו: גבוה
איסוף סטטוס안 מותר רק למנהל מערכת</translation>
    </message>
    <message>
        <source>Audit log is not exist.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation>הצג את הלוגים לנתיב המבוקש</translation>
    </message>
    <message>
        <source>PATH</source>
        <translation>נתיב</translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation>הצג את הלוגים המבוקשים</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>סוג</translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation>הצג את הלוגים של אפליקציות מתפתחות במערכת</translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation>שם אפליקציה מתפתחת</translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation>הצג את הלוגים בתIME מוגבל</translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation>תקופה</translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation>הצג את הלוגים בתLvL מוגבל</translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation>LvL</translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation>מצב התחלה</translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation>הצג את הלוגים של התחלה (בלי-KLU) בתLvL מוגבל</translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation>הצג את הלוגים של התחלה-סיום או סטטוס안 בתTp מוגבל</translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation>סוג אירוע</translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation>הצג רישומים לפי תוצאות חיפוש מילים מפתח</translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation>מילה מפתח</translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation>הצג מידע על הפלט של קורדUMP.</translation>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation>הצג רישומים לפי תת-מודל האפליקציה</translation>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation>תת-מודול</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>.&apos;] אינטרוול להתחדשות</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 שניות</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 דקה</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 דקות</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>לא להתחדש</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>הצג הכל</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>תחדש עכשיו</translation>
    </message>
</context>
</TS>